==> plasma-framework-4.98.0.zip: plasma-framework-4.98.0/src/declarativeimports/platformcomponents/icondialog.cpp <==
/*
 *   Copyright (C) 2014 Ivan Cukic <ivan.cukic(at)kde.org>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2,
 *   or (at your option) any later version, as published by the Free
 *   Software Foundation
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "icondialog.h"

#include "utils/d_ptr_implementation.h"

#include <QDebug>

#include <KIconDialog>
#include <KWindowSystem>

#include "utils/sharedsingleton.h"

/**
 *
 */
class IconDialog::Private {
public:

    utils::SharedSingleton<KIconDialog> dialog;
};

IconDialog::IconDialog(QObject * parent)
    : QObject(parent)
{
}

QString IconDialog::openDialog()
{
    auto dialog = d->dialog.instance();

    dialog->setup(KIconLoader::Desktop);
    dialog->setProperty("DoNotCloseController", true);

    KWindowSystem::setOnAllDesktops(dialog->winId(), true);

    dialog->showDialog();
    KWindowSystem::forceActiveWindow(dialog->winId());

    return dialog->openDialog();
}

void IconDialog::closeDialog()
{
    if (d->dialog) {
        auto dialog = d->dialog.instance();
        dialog->close();
    }
}

IconDialog::~IconDialog()
{
}

==> plasma-framework-5.65.0.zip: plasma-framework-5.65.0/src/declarativeimports/platformcomponents/icondialog.cpp <==
/*
 *   Copyright (C) 2014 Ivan Cukic <ivan.cukic(at)kde.org>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2,
 *   or (at your option) any later version, as published by the Free
 *   Software Foundation
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "icondialog.h"

#include "utils/d_ptr_implementation.h"

#include <QDebug>

#include <KIconDialog>
#include <KWindowSystem>

#include "utils/sharedsingleton.h"

/**
 *
 */
class IconDialog::Private
{
public:

    utils::SharedSingleton<KIconDialog> dialog;
};

IconDialog::IconDialog(QObject *parent)
    : QObject(parent)
{
}

QString IconDialog::openDialog()
{
    auto dialog = d->dialog.instance();

    dialog->setup(KIconLoader::Desktop);
    dialog->setProperty("DoNotCloseController", true);

    KWindowSystem::setOnAllDesktops(dialog->winId(), true);

    dialog->showDialog();
    KWindowSystem::forceActiveWindow(dialog->winId());

    return dialog->openDialog();
}

void IconDialog::closeDialog()
{
    if (d->dialog) {
        auto dialog = d->dialog.instance();
        dialog->close();
    }
}

IconDialog::~IconDialog()
{
}
